# Changelog
All notable changes to this project will be documented in this file

## [0.2.3] - 2021-10-10
### Added
- User can input comment style

## [0.2.2] - 2021-10-05
### Fixed
- Handle non text files


## [0.2.1] - 2021-10-04
### Added
- Version argument

### Fixed
- Wrong Changelog version number

## [0.2.0] - 2021-10-04
### Added
- Insert code sections to text files with recursive glob
    - Delimiter setting used to mark section insertion

### Changed
- Mutually exclusive arguments
- Title is now an optional argument
- Default behavior without arguments now prints help and preview

### Fixed
- Malformed "Changelog" entry in pyproject.toml

## [0.1.1] - 2021-09-30
### Added
- CHANGELOG.md to document changes to program
- Homepage and Changelog entry in pyproject spec 

## [0.1.0] - 2021-09-29
- Initial commit